##  Diagrams in Architecture Decisions
You can embed diagrams in architecture decisions to add context, compare options, or show dependencies, risks, and timelines. When you embed a diagram, the system creates a two-way link between the decision and the diagram. This means:
  * The latest version of the diagram appears in the decision.
  * The diagram shows a list of decisions that reference it. You can navigate back to those decisions.


![Architecture decision page showing a dataflow diagram.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio925bbe8b32cc40a885d9b2c62edfb43e_LowRes.png)
Architecture Decision with a Diagram
To embed a diagram, choose the diagram icon ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio1f3cfcc3cb894dc2b3d0a20b50451923_LowRes.png) in the toolbar, then select a diagram. Note the following:
  * You can include multiple diagrams in a decision to compare options.
  * The latest version of a diagram is displayed.
  * Only users with appropriate permissions can view diagrams in decisions. If you don't have access to a diagram with restricted permissions, it appears as a gray box.
